@@ -1,6 +1,6 @@
 /* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
 /* ***** BEGIN LICENSE BLOCK *****
- * Version: MPL 1.1
+ * Version: MPL 1.1/GPL 2.0/LGPL 2.1
  *
  * The contents of this file are subject to the Mozilla Public License Version
  * 1.1 (the "License"); you may not use this file except in compliance with
@@ -27,6 +27,18 @@
  *   Terry Hayes <thayes@netscape.com>
  *   Kai Engert <kaie@netscape.com>
  *
+ * Alternatively, the contents of this file may be used under the terms of
+ * either the GNU General Public License Version 2 or later (the "GPL"), or
+ * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
+ * in which case the provisions of the GPL or the LGPL are applicable instead
+ * of those above. If you wish to allow use of your version of this file only
+ * under the terms of either the GPL or the LGPL, and not to allow others to
+ * use your version of this file under the terms of the MPL, indicate your
+ * decision by deleting the provisions above and replace them with the notice
+ * and other provisions required by the GPL or the LGPL. If you do not delete
+ * the provisions above, a recipient may use your version of this file under
+ * the terms of any one of the MPL, the GPL or the LGPL.
+ *
  * ***** END LICENSE BLOCK ***** */
 
 #ifdef MOZ_LOGGING
@@ -51,7 +63,7 @@
 #include "nsIDocumentViewer.h"
 #include "nsIDocument.h"
 #include "nsIDOMElement.h"
-#include "nsIDOMWindowInternal.h"
+#include "nsPIDOMWindow.h"
 #include "nsIContent.h"
 #include "nsIWebProgress.h"
 #include "nsIChannel.h"
@@ -66,9 +78,10 @@
 #include "nsIFormSubmitObserver.h"
 #include "nsISecurityWarningDialogs.h"
 #include "nsIProxyObjectManager.h"
+#include "nsNetUtil.h"
 #include "nsCRT.h"
 
-#define SECURITY_STRING_BUNDLE_URL "chrome://necko/locale/security.properties"
+#define SECURITY_STRING_BUNDLE_URL "chrome://pipnss/locale/security.properties"
 
 #define IS_SECURE(state) ((state & 0xFFFF) == STATE_IS_SECURE)
 
@@ -145,12 +158,6 @@ nsSecureBrowserUIImpl::nsSecureBrowserUIImpl()
 
 nsSecureBrowserUIImpl::~nsSecureBrowserUIImpl()
 {
-  nsresult rv;
-  // remove self from form post notifications:
-  nsCOMPtr<nsIObserverService> svc(do_GetService("@mozilla.org/observer-service;1", &rv));
-  if (NS_SUCCEEDED(rv)) {
-    svc->RemoveObserver(this, NS_FORMSUBMIT_SUBJECT);
-  }
   if (mTransferringRequests.ops) {
     PL_DHashTableFinish(&mTransferringRequests);
     mTransferringRequests.ops = nsnull;
@@ -170,8 +177,19 @@ NS_IMETHODIMP
 nsSecureBrowserUIImpl::Init(nsIDOMWindow *window)
 {
   PR_LOG(gSecureDocLog, PR_LOG_DEBUG,
-         ("SecureUI:%p: Init\n", this));
+         ("SecureUI:%p: Init: mWindow: %p, window: %p\n", this, mWindow.get(),
+          window));
 
+  if (!window) {
+    NS_WARNING("Null window passed to nsSecureBrowserUIImpl::Init()");
+    return NS_ERROR_INVALID_ARG;
+  }
+
+  if (mWindow) {
+    NS_WARNING("Trying to init an nsSecureBrowserUIImpl twice");
+    return NS_ERROR_ALREADY_INITIALIZED;
+  }
+  
   nsresult rv = NS_OK;
   mWindow = window;
 
@@ -188,12 +206,20 @@ nsSecureBrowserUIImpl::Init(nsIDOMWindow *window)
     rv = svc->AddObserver(this, NS_FORMSUBMIT_SUBJECT, PR_TRUE);
   }
   
-  /* GetWebProgress(mWindow) */
-  // hook up to the webprogress notifications.
   nsCOMPtr<nsIScriptGlobalObject> sgo(do_QueryInterface(mWindow));
   if (!sgo) return NS_ERROR_FAILURE;
-  
-  nsCOMPtr<nsIWebProgress> wp(do_GetInterface(sgo->GetDocShell()));
+
+  nsIDocShell *docShell = sgo->GetDocShell();
+
+  // The Docshell will own the SecureBrowserUI object
+  if (!docShell)
+    return NS_ERROR_FAILURE;
+
+  docShell->SetSecurityUI(this);
+
+  /* GetWebProgress(mWindow) */
+  // hook up to the webprogress notifications.
+  nsCOMPtr<nsIWebProgress> wp(do_GetInterface(docShell));
   if (!wp) return NS_ERROR_FAILURE;
   /* end GetWebProgress */
   
@@ -325,10 +351,18 @@ nsSecureBrowserUIImpl::Notify(nsIContent* formNode,
   nsCOMPtr<nsIDocument> document = formNode->GetDocument();
   if (!document) return NS_OK;
 
-  nsIURI *formURL = document->GetBaseURI();
+  nsIURI *formURL = document->GetDocumentURI();
+
+  nsCOMPtr<nsIDOMWindow> postingWindow =
+    do_QueryInterface(document->GetWindow());
+  // We can't find this document's window, cancel it.
+  if (!postingWindow)
+  {
+    NS_WARNING("If you see this and can explain why it should be allowed, note in Bug 332324");
+    *cancelSubmit = PR_TRUE;
+    return NS_OK;
+  }
 
-  nsCOMPtr<nsIDOMWindow> postingWindow(do_QueryInterface(document->GetScriptGlobalObject()));
-  
   PRBool isChild;
   IsChildOfDomWindow(mWindow, postingWindow, &isChild);
   
@@ -908,19 +942,16 @@ nsSecureBrowserUIImpl::OnStateChange(nsIWebProgress* aWebProgress,
 void nsSecureBrowserUIImpl::ObtainEventSink(nsIChannel *channel)
 {
   if (!mToplevelEventSink)
-  {
-    nsCOMPtr<nsIInterfaceRequestor> requestor;
-    channel->GetNotificationCallbacks(getter_AddRefs(requestor));
-    if (requestor)
-      mToplevelEventSink = do_GetInterface(requestor);
-  }
-
+    NS_QueryNotificationCallbacks(channel, mToplevelEventSink);
 }
 
 nsresult nsSecureBrowserUIImpl::UpdateSecurityState(nsIRequest* aRequest)
 {
   lockIconState newSecurityState;
 
+  PRBool showWarning = PR_FALSE;
+  lockIconState warnSecurityState;
+
   if (mNewToplevelSecurityState & STATE_IS_SECURE)
   {
     if (mNewToplevelSecurityState & STATE_SECURE_LOW
@@ -1014,7 +1045,7 @@ nsresult nsSecureBrowserUIImpl::UpdateSecurityState(nsIRequest* aRequest)
       high        high
     */
 
-    PRBool showWarning = PR_TRUE;
+    showWarning = PR_TRUE;
     
     switch (mPreviousSecurityState)
     {
@@ -1037,25 +1068,7 @@ nsresult nsSecureBrowserUIImpl::UpdateSecurityState(nsIRequest* aRequest)
     
     if (showWarning)
     {
-      switch (newSecurityState)
-      {
-        case lis_no_security:
-        case lis_broken_security:
-          ConfirmLeavingSecure();
-          break;
-
-        case lis_mixed_security:
-          ConfirmMixedMode();
-          break;
-
-        case lis_low_security:
-          ConfirmEnteringWeak();
-          break;
-
-        case lis_high_security:
-          ConfirmEnteringSecure();
-          break;
-      }
+      warnSecurityState = newSecurityState;
     }
 
     mPreviousSecurityState = newSecurityState;
@@ -1110,6 +1123,29 @@ nsresult nsSecureBrowserUIImpl::UpdateSecurityState(nsIRequest* aRequest)
 
   }
 
+  if (showWarning)
+  {
+    switch (warnSecurityState)
+    {
+      case lis_no_security:
+      case lis_broken_security:
+        ConfirmLeavingSecure();
+        break;
+
+      case lis_mixed_security:
+        ConfirmMixedMode();
+        break;
+
+      case lis_low_security:
+        ConfirmEnteringWeak();
+        break;
+
+      case lis_high_security:
+        ConfirmEnteringSecure();
+        break;
+    }
+  }
+
   return NS_OK; 
 }
 
@@ -1226,14 +1262,25 @@ nsSecureBrowserUIImpl::GetSSLStatus(nsISupports** _result)
 nsresult
 nsSecureBrowserUIImpl::IsURLHTTPS(nsIURI* aURL, PRBool* value)
 {
-	*value = PR_FALSE;
+  *value = PR_FALSE;
 
-	if (!aURL)
-		return NS_OK;
+  if (!aURL)
+    return NS_OK;
 
   return aURL->SchemeIs("https", value);
 }
 
+nsresult
+nsSecureBrowserUIImpl::IsURLJavaScript(nsIURI* aURL, PRBool* value)
+{
+  *value = PR_FALSE;
+
+  if (!aURL)
+    return NS_OK;
+
+  return aURL->SchemeIs("javascript", value);
+}
+
 void
 nsSecureBrowserUIImpl::GetBundleString(const PRUnichar* name,
                                        nsAString &outString)
@@ -1245,9 +1292,9 @@ nsSecureBrowserUIImpl::GetBundleString(const PRUnichar* name,
       outString = ptrv;
     else
       outString.SetLength(0);
-    
+
     nsMemory::Free(ptrv);
-    
+
   } else {
     outString.SetLength(0);
   }
@@ -1256,7 +1303,7 @@ nsSecureBrowserUIImpl::GetBundleString(const PRUnichar* name,
 nsresult
 nsSecureBrowserUIImpl::CheckPost(nsIURI *formURL, nsIURI *actionURL, PRBool *okayToPost)
 {
-  PRBool formSecure,actionSecure;
+  PRBool formSecure, actionSecure, actionJavaScript;
   *okayToPost = PR_TRUE;
 
   nsresult rv = IsURLHTTPS(formURL, &formSecure);
@@ -1266,21 +1313,30 @@ nsSecureBrowserUIImpl::CheckPost(nsIURI *formURL, nsIURI *actionURL, PRBool *oka
   rv = IsURLHTTPS(actionURL, &actionSecure);
   if (NS_FAILED(rv))
     return rv;
-  
+
+  rv = IsURLJavaScript(actionURL, &actionJavaScript);
+  if (NS_FAILED(rv))
+    return rv;
+
   // If we are posting to a secure link, all is okay.
   // It doesn't matter whether the currently viewed page is secure or not,
   // because the data will be sent to a secure URL.
   if (actionSecure) {
     return NS_OK;
   }
-    
+
+  // Action is a JavaScript call, not an actual post. That's okay too.
+  if (actionJavaScript) {
+    return NS_OK;
+  }
+
   // posting to insecure webpage from a secure webpage.
   if (formSecure) {
     *okayToPost = ConfirmPostToInsecureFromSecure();
   } else {
     *okayToPost = ConfirmPostToInsecure();
   }
-  
+
   return NS_OK;
 }
 
@@ -1325,6 +1381,10 @@ NS_IMETHODIMP nsUIContext::GetInterface(const nsIID & uuid, void * *result)
 
     rv = internal->GetPrompter(&prompt);
     *result = prompt;
+  } else if (uuid.Equals(NS_GET_IID(nsIDOMWindow))) {
+    *result = mWindow;
+    NS_ADDREF ((nsISupports*) *result);
+    rv = NS_OK;
   } else {
     rv = NS_ERROR_NO_INTERFACE;
   }
